package com.cultural.heritage.controller.wx;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.utils.ReflexObjectUtil;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;


@RestController
@RequestMapping("/wx")
@Slf4j
@Tag(name = "小程序获取公众号文章")
public class WeChatController {


    @PostMapping("/getArticle")
    public BaseResponse<Map<String, Object>> getArticleInfo() {
        String result1 = null;
        try {
            result1 = getToken();
            Map<String,Object> token = JSON.parseObject(result1);
            String result2 = getContentList(token.get("access_token").toString());
            JSONObject jsonObject = JSON.parseObject(result2);
            System.out.println(jsonObject);
            Map<String, Object> keyAndValue = ReflexObjectUtil.getKeyAndValue(jsonObject);
            return ResultUtils.success(keyAndValue);
        } catch (IOException e) {
            log.info("获取公众号文章信息错误");
            throw new BusinessException(ErrorCode.SYSTEM_ERROR);
        }
    }


    private String getToken() throws IOException {
        // access_token接口https请求方式: GET https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=APPID&secret=APPSECRET
        String path = " https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential";
        String appid = "wx5d04ca2de0e628a8";
        String secret = "495af5bc4df1b86ffcfc21bb12daea76";
        URL url = new URL(path+"&appid=" + appid + "&secret=" + secret);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setRequestMethod("GET");
        connection.connect();

        InputStream in = connection.getInputStream();
        byte[] b = new byte[100];
        int len = -1;
        StringBuffer sb = new StringBuffer();
        while((len = in.read(b)) != -1) {
            sb.append(new String(b,0,len));
        }

        System.out.println(sb);
        in.close();
        return sb.toString();
    }



    private String getContentList(String token) throws IOException {
        String path = " https://api.weixin.qq.com/cgi-bin/freepublish/batchget?access_token=" + token;
        URL url = new URL(path);
        HttpURLConnection connection = (HttpURLConnection) url.openConnection();
        connection.setRequestMethod("POST");
        connection.setDoOutput(true);
        connection.setRequestProperty("content-type", "application/json;charset=utf-8");
        connection.connect();
        // post发送的参数
        Map<String, Object> map = new HashMap<>();
        map.put("offset", 0); // news表示图文类型的素材，具体看API文档
        map.put("count", 20);
        map.put("no_content", 1);
        // 将map转换成json字符串
        String paramBody = JSON.toJSONString(map); // 这里用了Alibaba的fastjson

        OutputStream out = connection.getOutputStream();
        BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(out));
        bw.write(paramBody); // 向流中写入参数字符串
        bw.flush();

        InputStream in = connection.getInputStream();
        byte[] b = new byte[100];
        int len = -1;
        StringBuffer sb = new StringBuffer();
        while((len = in.read(b)) != -1) {
            sb.append(new String(b,0,len));
        }

        in.close();
        return sb.toString();
    }



}

