package com.cultural.heritage.model.dto.coupon;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

@Data
@Schema(description = "优惠券添加请求体", requiredProperties =
        {"name", "conditionAmount", "requirePoints", "totalNum", "residueNum", "limitNum", "useScope", "startTime", "endTime", "image", "description"})
public class CouponAddRequest implements Serializable {


    /**
     * 优惠券名称
     */
    @Schema(description = "优惠券名称", example = "满200减50")
    private String name;

    /**
     * 满减金额
     */
    @Schema(description = "满减金额", example = "50")
    private BigDecimal conditionAmount;


    /**
     * 需要的积分
     */
    @Schema(description = "兑换需要的积分", example = "1000")
    private Integer requirePoints;

    /**
     * 优惠券简介
     */
    @Schema(description = "优惠券简介", example = "满200减50，超值优惠")
    private String intro;


    /**
     * 发放数量
     */
    @Schema(description = "发放数量", example = "10")
    private Integer totalNum;


    /**
     * 剩余数量
     */
    @Schema(description = "剩余数量", example = "5")
    private Integer residueNum;


    /**
     * 用户限领量
     */
    @Schema(description = "用户限领量", example = "3")
    private Integer limitNum;

    /**
     * 作用范围
     */
    @Schema(description = "作用范围(商品类别名)", example = "材料包;手持物;头饰")
    private String useScope;

    /**
     * 有效开始日期
     */
    @Schema(description = "有效开始日期", example = "2024-11-04 15:00:00")
    private String startTime;


    /**
     * 有效截止日期
     */
    @Schema(description = "有效截止日期", example = "2024-12-04 15:00:00")
    private String endTime;


    /**
     * 优惠券图片
     */
    @Schema(description = "优惠券图片地址", example = "https://xxx/xxx.jpg")
    private String image;


    /**
     * 使用说明
     */
    @Schema(description = "使用说明", example = "该优惠券只作用于一个材料包类商品;取消订单后优惠券会自动退回")
    private String description;


    @Serial
    private static final long serialVersionUID = 1L;
}
